use jacderida_exp2_add_lib::{add_five, add_four, add_one, add_three, add_two};

fn main() {
    let x = 10;
    println!("Use add_one: {}", add_one(x));
    println!("Use add_two: {}", add_two(x));
    println!("Use add_three: {}", add_three(x));
    println!("Use add_four: {}", add_four(x));
    println!("Use add_five: {}", add_five(x));
}
